@@ -1,4 +1,5 @@
 package CPANPLUS::Internals::Report;
+use deprecate;
 
 use strict;
 
@@ -13,6 +14,9 @@ use Module::Load::Conditional   qw[can_load];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 use version;
 
+use vars qw[$VERSION];
+$VERSION = "0.9135";
+
 $Params::Check::VERBOSE = 1;
 
 ### for the version ###
